import React from "react";
import { motion } from "framer-motion";
import { LikeFilled, LikeOutlined, EyeOutlined, CommentOutlined } from "@ant-design/icons";

interface StatsButtonProps {
  icon: React.ReactNode;
  text: string;
  onClick?: () => void;
  isActive?: boolean;
}

export function StatsButton({ icon, text, onClick, isActive }: StatsButtonProps) {
  return (
    <motion.button
      whileHover={{ scale: 1.05 }}
      whileTap={{ scale: 0.95 }}
      onClick={onClick}
      className={`flex items-center gap-2 px-4 py-2 rounded-md ${
        isActive
          ? "bg-[#507AAF] text-white"
          : "bg-white text-[#2B4C7E] hover:bg-[#507AAF] hover:text-white"
      } transition-all duration-300 shadow-md border border-[#97A9C4]/30`}
    >
      {icon}
      <span className="font-medium">{text}</span>
    </motion.button>
  );
}

interface StatsSectionProps {
  likes: number;
  views: number;
  commentsCount: number;
  liked: boolean;
  onLikeClick: () => void;
}

export function StatsSection({
  likes,
  views,
  commentsCount,
  liked,
  onLikeClick,
}: StatsSectionProps) {
  return (
    <motion.div
      initial={{ opacity: 0, y: 20 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ delay: 0.7 }}
      className="mt-6 flex flex-wrap gap-4 justify-start items-center"
    >
      <StatsButton
        icon={liked ? <LikeFilled style={{ fontSize: 18 }} /> : <LikeOutlined style={{ fontSize: 18 }} />}
        text={`${likes} 有帮助`}
        onClick={onLikeClick}
        isActive={liked}
      />
      <StatsButton
        icon={<EyeOutlined style={{ fontSize: 18 }} />}
        text={`${views} 浏览`}
      />
      <StatsButton
        icon={<CommentOutlined style={{ fontSize: 18 }} />}
        text={`${commentsCount} 回复`}
      />
    </motion.div>
  );
}
