import { motion } from "framer-motion";
import { Tag } from "antd";
import { PostState } from "@nice/common";
import {
	ClockIcon,
	CheckCircleIcon,
	ExclamationCircleIcon,
} from "@heroicons/react/24/outline";

interface TitleSectionProps {
	title: string;
	state: PostState;
}

const stateColors = {
	[PostState.PENDING]: "orange",
	[PostState.PROCESSING]: "blue",
	[PostState.COMPLETED]: "green",
};

const stateLabels = {
	[PostState.PENDING]: "待处理",
	[PostState.PROCESSING]: "处理中",
	[PostState.COMPLETED]: "已完成",
};

export function TitleSection({ title, state }: TitleSectionProps) {
	return (
		<motion.div
			initial={{ opacity: 0 }}
			animate={{ opacity: 1 }}
			transition={{ delay: 0.2 }}
			className="relative mb-6 flex items-center gap-4">
			{/* Decorative Line */}
			<div className="absolute -left-2 top-1/2 -translate-y-1/2 w-1 h-8 bg-[#97A9C4]" />

			{/* Title */}
			<h1 className="text-2xl font-bold text-[#2B4C7E] pl-4 tracking-wider uppercase">
				{title}
			</h1>

			{/* State Tag */}
			{/* <motion.div
				initial={{ opacity: 0, x: -20 }}
				animate={{ opacity: 1, x: 0 }}
				// transition={{ delay: 0.45 }}
				whileHover={{ scale: 1.05 }}
				className="flex items-center gap-2 bg-white px-3 py-1.5 rounded-md border border-[#97A9C4]/50 shadow-md hover:bg-[#F8FAFC] transition-colors duration-300"> */}
			<Tag
				color={stateColors[state]}
				className="flex items-center gap-1.5 px-3 py-1 shadow-md rounded-md text-sm font-medium border-none">
				{state === PostState.PENDING && (
					<ExclamationCircleIcon className="h-4 w-4" />
				)}
				{state === PostState.PROCESSING && (
					<ClockIcon className="h-4 w-4" />
				)}
				{state === PostState.COMPLETED && (
					<CheckCircleIcon className="h-4 w-4" />
				)}
				{stateLabels[state]}
			</Tag>
			{/* </motion.div> */}
		</motion.div>
	);
}
